iface vmbr0 inet static
#--- Container 201
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 20122 -j DNAT --to 10.0.0.201:22
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 25565 -j DNAT --to 10.0.0.201:25565
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 25565 -j DNAT --to 10.0.0.201:25565
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 25567 -j DNAT --to 10.0.0.201:25567
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 25567 -j DNAT --to 10.0.0.201:25567
#---
#--- Container 207
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 20722 -j DNAT --to 10.0.0.207:22
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 20780 -j DNAT --to 10.0.0.207:8080
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 25566 -j DNAT --to 10.0.0.207:25566
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 25566 -j DNAT --to 10.0.0.207:25566
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 25576 -j DNAT --to 10.0.0.207:25576
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 25576 -j DNAT --to 10.0.0.207:25576
#---
#--- Container 208
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 7777 -j DNAT --to 10.0.0.208:7777
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 15000 -j DNAT --to 10.0.0.208:15000
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 15777 -j DNAT --to 10.0.0.208:15777
#---
#--- Container 102
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 139 -j DNAT --to 10.0.0.102:139
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 445 -j DNAT --to 10.0.0.102:445
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 137 -j DNAT --to 10.0.0.102:137
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 138 -j DNAT --to 10.0.0.102:138
#---
#--- Container 103
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 10011 -j DNAT --to 10.0.0.103:10011
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 10022 -j DNAT --to 10.0.0.103:10022
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 10443 -j DNAT --to 10.0.0.103:10443
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 30033 -j DNAT --to 10.0.0.103:30033
#---
#--- Container 204
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 26900 -j DNAT --to 10.0.0.204:26900
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 26901 -j DNAT --to 10.0.0.204:26901
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 26902 -j DNAT --to 10.0.0.204:26902
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 26903 -j DNAT --to 10.0.0.204:26903
#---
#--- Container 202
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 20222 -j DNAT --to 10.0.0.202:22
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2302 -j DNAT --to 10.0.0.202:2302
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2303 -j DNAT --to 10.0.0.202:2303
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2304 -j DNAT --to 10.0.0.202:2304
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2305 -j DNAT --to 10.0.0.202:2305
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2306 -j DNAT --to 10.0.0.202:2306
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2307 -j DNAT --to 10.0.0.202:2307
#---
#--- Container 205
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 20522 -j DNAT --to 10.0.0.205:22
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2402 -j DNAT --to 10.0.0.205:2402
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2403 -j DNAT --to 10.0.0.205:2403
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2404 -j DNAT --to 10.0.0.205:2404
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2405 -j DNAT --to 10.0.0.205:2405
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 2406 -j DNAT --to 10.0.0.205:2406
#---
#--- Container 209
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 20922 -j DNAT --to 10.0.0.209:22
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 27015 -j DNAT --to 10.0.0.209:27015
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 8211 -j DNAT --to 10.0.0.209:8211
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 25577 -j DNAT --to 10.0.0.209:25577
#---
#--- Container 211
        post-up iptables -t nat -A PREROUTING -i eno1 -p tcp --dport 21122 -j DNAT --to 10.0.0.211:22
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 15636 -j DNAT --to 10.0.0.211:15636
        post-up iptables -t nat -A PREROUTING -i eno1 -p udp --dport 15637 -j DNAT --to 10.0.0.211:15637
#---
